@@ -28,7 +28,7 @@ Moose::Exporter->setup_import_methods(
     as_is => [qw/get_options/],
 );
 
-our $VERSION = version->new('0.2.6');
+our $VERSION = version->new('0.2.7');
 our $EXIT    = 1;
 
 has options => (
@@ -127,18 +127,22 @@ around BUILDARGS => sub {
         %param  = %{ $params[0] };
         @params = @{ $params[1] };
     }
+    elsif ( !%param && ref $params[0] eq 'HASH' ) {
+        %param = %{ shift @params };
+    }
 
     if ( !exists $param{helper} || $param{helper} ) {
         unshift @params, (
             'help',
             'man',
-            'VERSION',
+            'version',
             'auto_complete|auto-complete',
             'auto_complete_list|auto-complete-list!',
         );
     }
 
     if ( @params ) {
+        # construct a class of options passing
         my $class_name = 'Getopt::Alt::Dynamic::A' . $count++;
         my $object = Moose::Meta::Class->create(
             $class_name,
@@ -164,9 +168,10 @@ sub BUILD {
         stems   => [ "$prefix$basename", File::HomeDir->my_home . "/$prefix$basename", "/etc/$basename" ],
         use_ext => 1,
     });
+
     $conf = {
-        map { %$_        }
-        map { values %$_ }
+        map { $_ ? %$_ : () }
+        map { values %$_    }
         @{ $conf || [] }
     };
 
@@ -326,7 +331,7 @@ sub process {
     }
 
     if ( $self->help_package ) {
-        if ( $self->opt->{VERSION} ) {
+        if ( $self->opt->{version} ) {
              my ($name)  = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
              my $version = defined $main::VERSION ? $main::VERSION : 'undef';
              die Getopt::Alt::Exception->new( message => "$name Version = $version\n", help => 1);
@@ -452,16 +457,17 @@ __END__
 
 =head1 NAME
 
-Getopt::Alt - Alternate method of processing command line arguments
+Getopt::Alt - Command line option passing with with lots of features
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt version 0.2.6.
+This documentation refers to Getopt::Alt version 0.2.7.
 
 =head1 SYNOPSIS
 
    use Getopt::Alt;
 
+   # OO Style usage
    # Create a new options object
    my $opt = Getopt::Alt->new(
        {
@@ -560,9 +566,12 @@ This documentation refers to Getopt::Alt version 0.2.6.
 =head1 DESCRIPTION
 
 The aim of C<Getopt::Alt> is to provide an alternative to L<Getopt::Long> that
-allows a simple command line program to easily grow in complexity. It  or to a
-package with multiple commands. The simple usage is quite similar to
-L<Getopt::Long>:
+allows a simple command line program to easily grow in complexity. L<Getopt::Lon>
+can be expanded from a simple command line option passer to allow sub-commands.
+Option processing may stop at the sub-command or with the help of modules can
+cascade the processing into the sub command's module or config.
+
+The simple usage is quite similar to L<Getopt::Long>:
 
 In C<Getopt::Long> you might get your options like:
 
@@ -644,34 +653,39 @@ Any arguments that not consumed as part of options (usually files), if no
 arguments were passed to C<process> then this value would also be put back
 into C<@ARGV>.
 
-=item C<bundle> - bool
+=item C<bundle> - bool (Default true)
 
 Turns on bundling of arguments eg C<-rv> is equivalent to C<-r -v>. This is
 on by default.
 
-=item C<ignore_case> - bool
+=item C<ignore_case> - bool (Default true)
 
 Turns ignoring of the case of arguments, off by default.
 
 =item C<helper> - bool
 
-If set to a true value this will cause the help, man, and VERSION options to
-be added the end of your
+If set to a true value this will cause the help, man, and version options to
+be added the end of your options list. (i.e. you get --help --man and
+--version arguments for you program.)
 
-=item C<help_package> -
+=item C<help_package> - Str
 
 The Perl package with the POD documentation for --help and --man, by default
 it's the callers package.
 
+=item C<name> - Str (Default $0's basename)
+
+Used when displaying --version info
+
 =item C<cmds> - ArrayRef[Getopt::Alt::Command]
 
 If the Getopt::Alt is being used as part of a package where individual
 commands have their own modules this parameter stores an instance of each
 commands. (Not yet fully implemented.
 
-=item C<options> - ArrayRef[Getopt::Alt::Option]
+=item C<options> - Str (Default Getopt::Alt::Dynamic)
 
-The individual command option specifications processed.
+The parent class for generating options.
 
 =item C<opt> - HashRef
 
@@ -689,11 +703,28 @@ When using sub-commands this allows you to configure aliases for those
 commands, aliases are recursed, they can have extra arguments though.
 If a configuration file is used aliases can be specified in that file.
 
+=item C<conf_prefix> - Str (Default ".")
+
+The prefix for finding the configuration files. By default the following
+is used:
+
+=over 4
+
+=item *
+
+./$conf_prefix$name
+
+=item *
+
+~/$conf_prefix$name
+
+=item *
+
+/etc/$conf_prefix$name
+
 =back
 
-Return: Getopt::Alt -
-
-Description:
+=back
 
 =head2 Object Methods
 
